==> ejc-assistrmat-impl-3.0.0-20220322.020504-1-sources.jar: com/ejianc/business/assist/rmat/bean/SettleNumRentEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算单-工程量租金额
 *
 * @author generator
 */
@TableName("ejc_prormat_settle_num_rent")
public class SettleNumRentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "material_type_id")
    private Long materialTypeId; // 物资材料分类Id
    @TableField(value = "material_type_name")
    private String materialTypeName; // 物资材料分类名称
    @TableField(value = "material_id")
    private Long materialId; // 材料id
    @TableField(value = "material_code")
    private String materialCode; // 材料编码
    @TableField(value = "material_name")
    private String materialName; // 材料名称
    @TableField(value = "spec")
    private String spec; // 规则/型号
    @TableField(value = "unit_id")
    private Long unitId; // 计量单位id
    @TableField(value = "unit_name")
    private String unitName; // 计量单位名称
    @TableField(value = "num")
    private BigDecimal num; // 数量
    @TableField(value = "unit_tax_price")
    private BigDecimal unitTaxPrice; // 租赁单价
    @TableField(value = "unit_price")
    private BigDecimal unitPrice; // 租赁单价(无税)
    @TableField(value = "tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value = "num_rent_tax_mny")
    private BigDecimal numRentTaxMny; // 工程量租金
    @TableField(value = "num_rent_mny")
    private BigDecimal numRentMny; // 工程量租金(无税)
    @TableField(value = "num_tax")
    private BigDecimal numTax; // 税额
    @TableField(value = "start_date")
    private Date startDate; // 计费开始日期
    @TableField(value = "end_date")
    private Date endDate; // 计费结束日期
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getNumRentTaxMny() {
        return numRentTaxMny;
    }

    public void setNumRentTaxMny(BigDecimal numRentTaxMny) {
        this.numRentTaxMny = numRentTaxMny;
    }

    public BigDecimal getNumRentMny() {
        return numRentMny;
    }

    public void setNumRentMny(BigDecimal numRentMny) {
        this.numRentMny = numRentMny;
    }

    public BigDecimal getNumTax() {
        return numTax;
    }

    public void setNumTax(BigDecimal numTax) {
        this.numTax = numTax;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-assistrmat-impl-3.0.0-20220322.073307-3-sources.jar: com/ejianc/business/assist/rmat/bean/SettleNumRentEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 结算单-工程量租金额
 *
 * @author generator
 */
@TableName("ejc_assistrmat_settle_num_rent")
public class SettleNumRentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "settle_id")
    private Long settleId; // 结算id
    @TableField(value = "source_id")
    private Long sourceId; // 来源数据Id
    @TableField(value = "material_type_id")
    private Long materialTypeId; // 物资材料分类Id
    @TableField(value = "material_type_name")
    private String materialTypeName; // 物资材料分类名称
    @TableField(value = "material_id")
    private Long materialId; // 材料id
    @TableField(value = "material_code")
    private String materialCode; // 材料编码
    @TableField(value = "material_name")
    private String materialName; // 材料名称
    @TableField(value = "spec")
    private String spec; // 规则/型号
    @TableField(value = "unit_id")
    private Long unitId; // 计量单位id
    @TableField(value = "unit_name")
    private String unitName; // 计量单位名称
    @TableField(value = "num")
    private BigDecimal num; // 数量
    @TableField(value = "unit_tax_price")
    private BigDecimal unitTaxPrice; // 租赁单价
    @TableField(value = "unit_price")
    private BigDecimal unitPrice; // 租赁单价(无税)
    @TableField(value = "tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value = "num_rent_tax_mny")
    private BigDecimal numRentTaxMny; // 工程量租金
    @TableField(value = "num_rent_mny")
    private BigDecimal numRentMny; // 工程量租金(无税)
    @TableField(value = "num_tax")
    private BigDecimal numTax; // 税额
    @TableField(value = "start_date")
    private Date startDate; // 计费开始日期
    @TableField(value = "end_date")
    private Date endDate; // 计费结束日期
    @TableField(value = "memo")
    private String memo; // 备注


    public Long getSettleId() {
        return settleId;
    }

    public void setSettleId(Long settleId) {
        this.settleId = settleId;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public BigDecimal getNumRentTaxMny() {
        return numRentTaxMny;
    }

    public void setNumRentTaxMny(BigDecimal numRentTaxMny) {
        this.numRentTaxMny = numRentTaxMny;
    }

    public BigDecimal getNumRentMny() {
        return numRentMny;
    }

    public void setNumRentMny(BigDecimal numRentMny) {
        this.numRentMny = numRentMny;
    }

    public BigDecimal getNumTax() {
        return numTax;
    }

    public void setNumTax(BigDecimal numTax) {
        this.numTax = numTax;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
